#! /bin/sh

### MPD Link-up Script ########################################################
#                                                                             #
#  Usage(IPv4) :                                                              #
#          mpdlnkup.sh interface proto local-ip remote-ip \                   #
#          authname dns1-server-ip dns2-server-ip peer-address                #
#  Usage(IPv6) :                                                              #
#          mpdlnkup.sh interface proto local-ip remote-ip \                   #
#          authname peer-address                                              #
#                                                                             #
#  (interface)      : interface name which assigned the new address by PPP    #
#  (proto)          : protocol name ("inet" if IPv4, "inet6" if IPv6)         #
#  (local-ip)       : the localside IP address assigned by PPP                #
#  (remote-ip)      : the opposite IP address assigned by PPP                 #
#  (dns1-server-ip) : the primary DNS server address notified with IPCP       #
#  (dns2-server-ip) : the secondary DNS server address notified with IPCP     #
#  (authname)       : username used by PPP authentication                     #
#  (peer-address)   : peer MAC address argument given by mpd                  #
#                                                                             #
#  note: MPD link-up script given the following sample arguments              #
#        "ng0" "inet" "1.2.3.4/32" "5.6.7.8" "-" "dns1 8.7.6.5" \             #
#        "dns2 4.3.2.1" "00:00:00:00:00:00"                                   #
#                                                                             #
###############################################################################


# =============================================================================
# Definition
# =============================================================================
#
# ----- define common variables and functions -----
. /usr/local/richscripts/etc/common.lib

# =============================================================================
# Parse the arguments
# -----------------------------------------------------------------------------
#  1. parse new IP address
#  2. parse nameservers, and so on
#  3. show help message and exit if not enough argument
# =============================================================================
#
# ----- 1. 2. parse new IP address, nameservers, and so on -----
if="$1"
proto="$2"
auth_name="$5"
case "$proto" in
  inet)
    local_ip="$3"
    local_ip=${local_ip%/*}
    remote_ip="$4"
    remote_ip=${remote_ip%/*}
    dns1_ip=$6
    dns1_ip=${dns1_ip#* }
    if [ -z "`echo "$dns1_ip" | $CMD_GREP -E $PATTERN_IPV4`" ]; then
      dns1_ip=""
    fi
    dns2_ip=$7
    dns2_ip=${dns2_ip#* }
    if [ -z "`echo "$dns2_ip" | $CMD_GREP -E $PATTERN_IPV4`" ]; then
      dns2_ip=""
    fi
    remote_addr=$8
    ;;
  inet6)
    remote_addr=$6
    ;;
  *)
    remote_addr="BAD_PROTO"
    ;;
esac
# ----- 4. show help message and exit if the arguments are not enough -----
if [ "_$remote_addr" = "_BAD_PROTO" ]; then
  echo "Usage(IPv4) : ${0##*/} interface proto local-ip remote-ip \ "
  echo "              authname dns1-server-ip dns2-server-ip peer-address"
  echo "Usage(IPv6) : ${0##*/} interface proto local-ip remote-ip \ "
  echo "              authname peer-address"
  echo " - interface      : interface name which assigned the new address by PPP"
  echo " - proto          : protocol name ("inet" if IPv4, "inet6" if IPv6)"
  echo " - local-ip       : the localside IP address assigned by PPP"
  echo " - remote-ip      : the opposite IP address assigned by PPP"
  echo " - dns1-server-ip : the primary DNS server address notified with IPCP"
  echo " - dns2-server-ip : the secondary DNS server address notified with IPCP"
  echo " - authname       : username used by PPP authentication"
  echo " - peer-address   : peer-address argument given by mpd"
  debug_log "mpdlnkup.sh: the arguments are invalid"
  exit
fi


# =============================================================================
# Execute the PPP link-up script
# -----------------------------------------------------------------------------
#  1. decide unit number for the PPP link-up script
#  2. execute the PPP link-up script
# =============================================================================
#
# ----- 1. decide unit number -----
check=`echo "_$auth_name" | $CMD_GREP "@$FILE_NS_LIST_FLETS_FWD$"`
unit_num=${if##*[A-Za-z]}
#
# ----- 2. execute the PPP link-up script -----
if [ -n "$dns1_ip$dns2_ip" ]; then
  $PATH_PPPLNKUP -u $unit_num -i $local_ip -n $dns1_ip $dns2_ip
else
  $PATH_PPPLNKUP -u $unit_num -i $local_ip
fi
